/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Stuart Parmenter <pavlov@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * gfx image formats.
 * @file gfxIFormats.idl
 */

#include "gfxtypes.idl"

/**
 * gfxIFormats interface
 *
 * @author Tim Rowley <tor@cs.brown.edu>
 * @author Stuart Parmenter <pavlov@netscape.com>
 * @version 0.0
 * @see gfx_format
 */
[scriptable, uuid(96d086e6-1dd1-11b2-b6b2-b77b59390247)]
interface gfxIFormats
{
  /**
   * RGB    - duh...
   */
  const gfx_format RGB    = 0;

  /**
   * BGR    - same as RGB except byteswaped
   */
  const gfx_format BGR    = 1;


  /**
   * RGB_A1 - RGB image and 1-bit alpha mask
   */
  const gfx_format RGB_A1 = 2;

  /**
   * BGR_A1 - same as RGB_A1 except byteswaped
   */
  const gfx_format BGR_A1 = 3;


  /**
   * RGB_A8 - RGB image and 8-bit alpha image
   */
  const gfx_format RGB_A8 = 4;

  /**
   * BGR_A8 - same as RGB_A8 except byteswaped
   */
  const gfx_format BGR_A8 = 5;


  /**
   * RGBA   - packed RGBA image
   */
  const gfx_format RGBA   = 6;

  /**
   * BGRA   - packed RGBA image
   */
  const gfx_format BGRA   = 7;

  /**
   * PAL    - Palette based image data, all opaque colors
   *		  PRUint32 colormap[256];
   *		  PRUint8 pixels[width*height];
   */
  const gfx_format PAL    = 8;

  /**
   * PAL_A1 - Palette based image data, with transparency
   *		  PRUint32 colormap[256];
   *		  PRUint8 pixels[width*height];
   */
  const gfx_format PAL_A1 = 9;
};
